@@ -1,8 +1,4 @@
-library(testthat)
-
-context("Loading packages")
-
-test_that('loaded packages', {
+test_that("loaded packages", {
   loaded <- names(sessionInfo()$otherPkgs)
   expect_true(
     all(tidymodels:::core %in% loaded)
@@ -10,7 +6,7 @@ test_that('loaded packages', {
 })
 
 
-test_that('should not be loaded', {
+test_that("should not be loaded", {
   loaded <- names(sessionInfo()$otherPkgs)
   expect_true(
     all(!(c("rlang", "tidyselect") %in% loaded))
